import merge from 'deepmerge';
import color from 'color';
export const defaultTheme = {
    colors: {
        primary: '#C7C7CB',
        secondary: '#E3E3E5',
        primaryText: '#76767C',
        secondaryText: '#B9B9BC',
        red: '#E82C2C',
        orange: '#E8A72C',
        yellow: '#EFEF2C',
        green: '#24D174',
        teal: '#09D0B1',
        blue: '#2CB2E8',
        purple: '#A913E0',
        pink: '#FC42AD',
        brown: '#814306',
        black: '#151515',
        grey: '#A0A0A0',
        white: '#fff',
    },
    greyscale: {
        light: '#F5F5F5',
        medium: '#ECECEC',
        dark: '#C7C7CB',
        darker: '#76767C',
        darkest: '#393941',
    },
    font: {
        size: {
            default: '14px',
            h1: '18px',
            h2: '16px',
            h3: '14px',
        },
        family: "'Titillium Web','Helvetica Neue',Arial,Helvetica,sans-serif;",
    },
    sizes: {
        borderRadius: '1.5em',
    },
    breakpoints: ['40em', '52em', '64em', '80em'],
};
const getColors = (colors) => {
    let res = {};
    for (const key in colors) {
        if (colors.hasOwnProperty(key)) {
            const cHex = colors[key];
            const c = color(cHex);
            if (key.endsWith('Text')) {
                res[key] = {
                    default: cHex,
                    active: (c.isDark() ? c.darken(0.2) : c.lighten(0.4)).hex(),
                    hover: (c.isDark() ? c.lighten(0.4) : c.darken(0.2)).hex(),
                };
                continue;
            }
            res[key] = {
                default: cHex,
                active: (c.isLight() ? c.darken(0.1) : c.lighten(0.2)).hex(),
                hover: (c.isLight() ? c.lighten(0.2) : c.darken(0.1)).hex(),
            };
        }
    }
    return res;
};
export const createTheme = (theme) => {
    const { colors, ...rest } = theme ? merge(defaultTheme, theme) : defaultTheme;
    return {
        colors: getColors(colors),
        ...rest,
    };
};
export const defaultCreatedTheme = createTheme();
export default defaultCreatedTheme;
