export type HiroColors =
  | 'primary'
  | 'secondary'
  | 'primaryText'
  | 'secondaryText'
  | 'red'
  | 'orange'
  | 'yellow'
  | 'green'
  | 'teal'
  | 'blue'
  | 'purple'
  | 'pink'
  | 'brown'
  | 'black'
  | 'grey'
  | 'white';

export type Greyscales = 'light' | 'medium' | 'dark' | 'darker' | 'darkest';

type RecursivePartial<T> = {
  [P in keyof T]: RecursivePartial<T[P]>;
};

export type ColorDefinitions = Record<
  HiroColors,
  {
    default: string;
    active: string;
    hover: string;
  }
>;

export interface FontDefinitons {
  family: string;
  size: Record<'default' | 'h1' | 'h2' | 'h3', string | number>;
}

export type GreyscaleDefinitions = {
  [K in Greyscales]: string;
};

export interface SizeDefinitions {
  borderRadius: string | number;
}

export interface HiroDefaultTheme {
  colors: Record<HiroColors, string>;
  greyscale: GreyscaleDefinitions;
  font: FontDefinitons;
  sizes: SizeDefinitions;
  breakpoints: string[];
}
export type HiroPartialTheme = RecursivePartial<HiroDefaultTheme>;

declare module 'styled-components' {
  export interface DefaultTheme {
    colors: ColorDefinitions;
    greyscale: GreyscaleDefinitions;
    font: FontDefinitons;
    sizes: SizeDefinitions;
    breakpoints: string[];
  }
}
